aclust: Generate (perhaps approximate) dendrogram for heirarchical...

Description Usage Arguments Details Value

Description

mat must be a numeric matrix with row labels. mat will be column normalized before clustering. So no column can have constant values.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
aclust(
  mat,
  method = "ward",
  distance = "euclidean",
  p = 2,
  pcLimit = 512,
  pcSize = 128,
  pcMaxRows = 2048,
  hclustMax = 25000
)

Arguments

mat

A numeric matrix with row labels

method

Agglomeration method passed to hclust

distance

Distance metric passed to hclust

p

Minkowski distance parameter passed to hclust

pcLimit

Maximum number of columns before using principal components

pcSize

Number of principal components to use

pcMaxRows

Maximum number of rows to use for principle components

hclustMax

Maximum number to rows to hclust at a time

Details

Approximate methods will be employed if:

Rclusterpp::Rclusterpp.hclust will be used for (subsets of) the matrix with at most hclustMax rows. The parameters method, distance, and p are passed to it without modification.

Value

A dendrogram for the rows of mat


MD-Anderson-Bioinformatics/acluster documentation built on Dec. 17, 2021, 1:19 a.m.