rescale: Rescale a dendrogram based on a data matrix.

Description Usage Arguments Value

Description

Recalculate the height of the dendrogram branches based on the within- cluster sum of differences of the data within the numeric matrix mat. All labels of ddg must correspond to rows in mat.

Usage

1
rescale(ddg, mat)

Arguments

ddg

A dendrogram

mat

A numeric matrix with row labels that include all the labels in ddg.

Value

A dendrogram rescaled so that node heights equal the total within-cluster differences in mat.


MD-Anderson-Bioinformatics/acluster documentation built on Dec. 17, 2021, 1:19 a.m.