Description Usage Arguments Details Value
mat must be a numeric matrix with row labels. mat will be column normalized before clustering. So no column can have constant values.
1 2 3 4 5 6 7 8 9 10 | aclust(
mat,
method = "ward",
distance = "euclidean",
p = 2,
pcLimit = 512,
pcSize = 128,
pcMaxRows = 2048,
hclustMax = 25000
)
|
mat |
A numeric matrix with row labels |
method |
Agglomeration method passed to hclust |
distance |
Distance metric passed to hclust |
p |
Minkowski distance parameter passed to hclust |
pcLimit |
Maximum number of columns before using principal components |
pcSize |
Number of principal components to use |
pcMaxRows |
Maximum number of rows to use for principle components |
hclustMax |
Maximum number to rows to hclust at a time |
Approximate methods will be employed if:
the number of columns exceeds pcLimit (default 512): Clustering will be performed using the first pcSize (default 128) principal components. If the number of rows exceeds pcMaxRows (default 2048), the principal components will be approximated using pcMaxRows randomly selected rows.
the number of rows exceeds hclustMax (default 25000), the rows will partitioned using kmeans 2 as many times as required until each partition has at most hclustMax rows.
Rclusterpp::Rclusterpp.hclust will be used for (subsets of) the matrix with at most hclustMax rows. The parameters method, distance, and p are passed to it without modification.
A dendrogram for the rows of mat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.