Description Usage Arguments Value
Recalculate the height of the dendrogram branches based on the within- cluster sum of differences of the data within the numeric matrix mat. All labels of ddg must correspond to rows in mat.
1 | rescale(ddg, mat)
|
ddg |
A dendrogram |
mat |
A numeric matrix with row labels that include all the labels in ddg. |
A dendrogram rescaled so that node heights equal the total within-cluster differences in mat.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.